MomentModel

Struct MomentModel 

pub struct MomentModel { /* private fields */ }

Implementations

Source

impl MomentModel

pub fn load(gguf_path: &Path, config: MomentConfig) -> Result<Self>

pub fn forecast(&self, context: &[f32], horizon: usize) -> Result<Vec<f32>>

Zero-shot forecasting via single-pass masked inpainting.

Appends n_forecast_patches zero-filled future patches after the 64 context patches and runs ONE T5 encoder pass. The bidirectional encoder fills the masked future positions using the real context, mirroring the masking pretraining task. Head applied to future positions gives the forecast.